@@ -17,7 +17,7 @@ use Carp;
 use Business::CompanyDesignator::Record;
 use Business::CompanyDesignator::SplitResult;
 
-our $VERSION = '0.10';
+our $VERSION = '0.12';
 
 has 'datafile' => ( is => 'ro', default => sub {
   # Development/test version
@@ -113,6 +113,8 @@ sub _add_to_assembler {
   my @pattern = map {
     # Periods are treated as optional literals, with optional trailing commas and/or whitespace
     /\./   ? '\\.?,?\\s*?' :
+    # Embedded spaces can be multiple, and include leading commas
+    / /    ? ',?\s+' :
     # Escape other regex metacharacters
     /[()]/ ? "\\$_" : $_
   } split //, $string;
@@ -214,6 +216,9 @@ sub _split_designator_result {
   if ($matched_pattern) {
     $des_std = $self->pattern_string_map->{$matched_pattern}
       or die "Cannot find matched pattern '$matched_pattern' in pattern_string_map";
+    # Always coalesce spaces and delete commas from $des_std
+    $des_std =~ s/,+/ /g;
+    $des_std =~ s/\s\s+/ /g;
   }
 
   # Legacy interface - return a simple before / des / after tuple, plus $des_std
@@ -244,23 +249,25 @@ sub split_designator {
   $allow_embedded //= 1;    # backwards-compatibility, unfortunately
   my $company_name_match = NFD($company_name);
 
+  # Handle older perls without XPosixPunct
+  state $punct_class = eval { '.' =~ m/\p{XPosixPunct}/ } ? '\p{XPosixPunct}' : '[[:punct:]]';
+
   my ($re, $assembler) = $self->regex('end', $lang);
   my ($lead_re, $lead_assembler) = $self->regex('begin', $lang);
+  # For leading designators, require either trailing punctuation or whitespace
+  my $lead_break = qr/(?:(?<=${punct_class})|\s)/;
 
   if ($re) {
-    # Handle older perls without XPosixPunct
-    my $punct_class = eval { '' =~ m/\p{XPosixPunct}/ } ? qr/\p{XPosixPunct}*/ : qr/\p{PosixPunct}*/;
-
     # Designators are usually final, so try that first
-    if ($company_name_match =~ m/^\s*(.*?)${punct_class}\s+($re)\s*$/) {
+    if ($company_name_match =~ m/^\s*(.*?)${punct_class}*\s+($re)\s*$/) {
       return $self->_split_designator_result($1, $2, undef, $assembler->source($^R));
     }
     # Not final - check for a lead designator instead (e.g. RU, NL, etc.)
-    elsif ($lead_re && $company_name_match =~ m/^\s*($lead_re)${punct_class}\s*(.*?)\s*$/) {
+    elsif ($lead_re && $company_name_match =~ m/^\s*($lead_re)${punct_class}*${lead_break}\s*(.*?)\s*$/) {
       return $self->_split_designator_result(undef, $1, $2, $lead_assembler->source($^R));
     }
     # Not final - check for an embedded designator with trailing content
-    elsif ($allow_embedded && $company_name_match =~ m/(.*?)${punct_class}\s+($re)(?:\s+(.*?))?$/) {
+    elsif ($allow_embedded && $company_name_match =~ m/(.*?)${punct_class}*\s+($re)(?:\s+(.*?))?$/) {
       return $self->_split_designator_result($1, $2, $3, $assembler->source($^R));
     }
   }
@@ -282,9 +289,9 @@ company designators appended to company names
 
 =head1 VERSION
 
-Version: 0.10.
+Version: 0.12.
 
-This module is considered an B<ALPHA> release. Interfaces may change and/or break
+This module is considered a B<BETA> release. Interfaces may change and/or break
 without notice until the module reaches version 1.0.
 
 =head1 SYNOPSIS
@@ -498,7 +505,7 @@ Gavin Carr <gavin@profound.net>
 
 =head1 COPYRIGHT AND LICENCE
 
-Copyright (C) 2013-2015 Gavin Carr
+Copyright (C) 2013-2016 Gavin Carr
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
